@@ -1,4 +1,5 @@
-name = 'vocmax'
+__name__ = 'vocmax'
+__version__ = '0.0.21'
 
 from vocmax.main import *
 import vocmax.nsrdb
\ No newline at end of file
